/**
 * @file defines InsertjwBoxCommand, which is executed when the jwBox
 * toolbar button is pressed.
 */
// cSpell:ignore jwboxediting

import { Command } from 'ckeditor5/src/core';

export default class InsertjwBoxCommand extends Command {
  execute() {
    const { model } = this.editor;
    var ajaxSettings = {
      url: '/admin/content/jw-media-modal'
    };
    var jwMediaViewForm = Drupal.ajax(ajaxSettings);
    jwMediaViewForm.execute();
      // Insert <jwBox>*</jwBox> at the current selection position
      // in a way that will result in creating a valid model structure.
      ( function($) {
        // Argument passed from InvokeCommand.
        $.fn.embedCallback = function(argument) {
          console.log('embedCallback is called.');
          model.change((writer) => {
            const jwScriptElement = createjwBox(writer, argument);
            model.insertContent(jwScriptElement);

          });
        };
      })(jQuery);
  }

  refresh() {
    const { model } = this.editor;
    const { selection } = model.document;

    // Determine if the cursor (selection) is in a position where adding a
    // jwBox is permitted. This is based on the schema of the model(s)
    // currently containing the cursor.
    const allowedIn = model.schema.findAllowedParent(
      selection.getFirstPosition(),
      'jwBox',
    );

    // If the cursor is not in a location where a jwBox can be added, return
    // null so the addition doesn't happen.
    this.isEnabled = allowedIn !== null;
  }
}

function createjwBox(writer, argument) {
  // Create instances of the three elements registered with the editor in
  // jwboxediting.js.
  const jwBox = writer.createElement('jwBox');
  const jwScript = writer.createElement('jwScript');
  // Append the title and description elements to the jwBox, which matches
  // the parent/child relationship as defined in their schemas.
  if(argument) {
    writer.setAttribute('src', argument, jwScript);
    console.log('jwScriptElement after setting src:', jwScript);
  }


  writer.append(jwScript, jwBox);


  // Return the element to be added to the editor.
  return jwBox;
}
