/**
 * @file registers the jwBox toolbar button and binds functionality to it.
 */

import { Plugin } from 'ckeditor5/src/core';
import { ButtonView } from 'ckeditor5/src/ui';
import icon from '../../../../icons/jwBox.svg';

export default class jwBoxUI extends Plugin {
  init() {
    const editor = this.editor;

    // This will register the jwBox toolbar button.
    editor.ui.componentFactory.add('jwBox', (locale) => {
      const command = editor.commands.get('insertjwBox');
      const buttonView = new ButtonView(locale);

      // Create the toolbar button.
      buttonView.set({
        label: editor.t('JW Box'),
        icon,
        tooltip: true,
      });

      // Bind the state of the button to the command.
      buttonView.bind('isOn', 'isEnabled').to(command, 'value', 'isEnabled');

      // Execute the command when the button is clicked (executed).
      this.listenTo(buttonView, 'execute', () =>
        editor.execute('insertjwBox'),
      );

      return buttonView;
    });
  }
}
